@@ -11,7 +11,7 @@ use DateTime::Duration;
 use Travel::Routing::DE::HAFAS::Utils;
 use Travel::Routing::DE::HAFAS::Connection::Section;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 Travel::Routing::DE::HAFAS::Connection->mk_ro_accessors(
 	qw(changes duration sched_dep rt_dep sched_arr rt_arr dep arr dep_platform arr_platform dep_loc arr_loc dep_cancelled arr_cancelled is_cancelled load)
@@ -89,6 +89,9 @@ sub new {
 
 	my @sections;
 	for my $sec (@secL) {
+		if ( $sec->{type} eq 'WALK' and not $sec->{gis}{durS} ) {
+			next;
+		}
 		push(
 			@sections,
 			Travel::Routing::DE::HAFAS::Connection::Section->new(
@@ -210,7 +213,7 @@ Travel::Routing::DE::HAFAS::Connection - A single connection between two stops
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 DESCRIPTION
 
